#
# spec file for package ghc-clock
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name clock
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.8.4
Release:        1.10
Summary:        High-resolution clock functions: monotonic, realtime, cputime
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
A package for convenient access to high-resolution clock and timer functions of
different operating systems via a unified API.

POSIX code and surface API was developed by Cetin Sert in 2009.

Windows code was contributed by Eugene Kirpichov in 2010.

FreeBSD code was contributed by Finn Espen Gundersen on 2013-10-14.

OS X code was contributed by Gerolf Seitz on 2013-10-15.

Derived 'Generic', 'Typeable' and other instances for 'Clock' and 'TimeSpec'
was contributed by Mathieu Boespflug on 2014-09-17.

Corrected dependency listing for 'GHC < 7.6' was contributed by Brian McKenna
on 2014-09-30.

Windows code corrected by Dimitri Sabadie on 2015-02-09.

Added 'timeSpecAsNanoSecs' as observed widely-used by Chris Done on 2015-01-06,
exported correctly on 2015-04-20.

Imported Control.Applicative operators correctly for Haskell Platform on
Windows on 2015-04-21.

Unit tests and instance fixes by Christian Burger on 2015-06-25.

Removal of fromInteger : Integer -> TimeSpec by Cetin Sert on 2015-12-15.

New Linux-specific Clocks: MonotonicRaw, Boottime, MonotonicCoarse,
RealtimeCoarse by Cetin Sert on 2015-12-15.

Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.

Fixes for older Linux build failures introduced by new Linux-specific clocks by
Mario Longobardi on 2016-04-18.

Refreshment release in 2019-04 after numerous contributions.

Refactoring for Windows, Mac implementation consistence by Alexander Vershilov
on 2021-01-16.

[Version Scheme] Major-'/R/'-ewrite . New-'/F/'-unctionality .
'/I/'-mprovementAndBugFixes . '/P/'-ackagingOnly

* 'PackagingOnly' changes are made for quality assurance reasons.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Jul 17 2023 Peter Simons <psimons@suse.com>
- Update clock to version 0.8.4.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Feb  9 2022 Peter Simons <psimons@suse.com>
- Update clock to version 0.8.3.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Sun Jan 24 2021 psimons@suse.com
- Update clock to version 0.8.2.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed May  1 2019 psimons@suse.com
- Update clock to version 0.8.
  Upstream does not provide a change log file.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.2 revision 0 with cabal2obs.
* Fri Apr 29 2016 mimi.vx@gmail.com
- update to 0.7.2
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 0.5.1
* Sun May 10 2015 mimi.vx@gmail.com
- update to 0.4.6.0
  * no upstream changelog
* Mon Apr 27 2015 mimi.vx@gmail.com
- update to 0.4.5.0
  * no upstream changelog
* Wed Apr 22 2015 mimi.vx@gmail.com
- initial commit
